      subroutine parseCubeCloud(prof,alat,alon,pc,cot)
c-------------------------------------------------------------------
c     Read one record from Cube simulated atmospheric profile file
c
c    Cube cloud information in the binary file (LENC=7)
c       CONTENT                DESCRIPTION       		UNIT
c       prof(1)=lat            Latitude 			Degrees
c       prof(2)=lon            Longitude 			Degrees
c       prof(3)=ltop           Cloud top with respect to liuid  hPa
c       prof(4)=itop           Cloud top with respect to ice    hPa
c       prof(5)=pc             Cloud top pressure               hPa
c       prof(6)=psurf          Surface pressure	                hPa
c       prof(7)=cot            cloud optical thickness          N/A

c
      implicit none

      include 'incRTVL.f'

      real*4 prof(lenc)
      real*4 alat, alon, cot,pc

      alat = prof(1)
      alon = prof(2)
      pc   = prof(5)
      cot  = prof(7)

      return
      end


      integer function get_cmask(prof)
      
c-------------------------------------------------------------------
c get cloud mask by cloud top respect to liquid and ice
c 0 -- clear, 1 -- cloud
c
c prof(3*nl+7)=ltop      Cloud top with respect to liuid  hPa
c prof(3*nl+8)=itop      Cloud top with respect to ice    hPa
c prof(3*nl+9)=psurf     Surface pressure	          hPa
c
      implicit none
      include 'incRTVL.f'
      real*4 prof(lenp)

      if (prof(3*nl+7).lt.prof(3*nl+9) .or.
     &    prof(3*nl+8).lt.prof(3*nl+9)) then
        get_cmask = 1
      else
        get_cmask = 0
      endif
      
      return
      end

      subroutine parseCube(prof,t,w,o,freqemis,emisir,rhoir,
     &             month,alat,alon,theta,psurf,tskn,emismw,work)
c-------------------------------------------------------------------
c     Read one record from Cube simulated atmospheric profile file
c
c     Cube profiles in the binary file (NL=101, LENG=3*NL+9)
c        CONTENT                DESCRIPTION       		UNIT
c        do L=1,nl              nl=101
c        prof(L)=tair(L)        Air temperature   		K 
c        prof(L+nl)=h2o(L)      Water vapor layer amount        g/kg
c        prof(L2*nl)=ozo(L)     Ozone layer amount		ppm
c        enddo
c        prof(3*nl+1)=lwp       Liquid water path	        g/m2
c        prof(3*nl+2)=iwp       Ice water path	                g/m2
c        prof(3*nl+3)=tsurf     Surface skin temperature        K
c        prof(3*nl+4)=ter       Terrain height                  m
c        prof(3*nl+5)=lat       Latitude 			Degrees
c        prof(3*nl+6)=lon       Longitude 			Degrees
c        prof(3*nl+7)=ltop      Cloud top with respect to liuid hPa
c        prof(3*nl+8)=itop      Cloud top with respect to ice   hPa
c        prof(3*nl+9)=psurf     Surface pressure	        hPa
c
      implicit none

      include 'incRTVL.f'

      integer*4 month, j, m
      real*4 prof(lenp)
      real*4 t(nl),w(nl),o(nl) 
      real*4 freqemis(ncemis), emisir(ncemis), rhoir(ncemis)
      real*4 alat, alon, theta, psurf, tskn, emismw, amonth
      real*4 work(nl)

      freqemis(1) = 769.0
      freqemis(2) = 909.0
      freqemis(3) = 1111.0
      freqemis(4) = 2105.0
      freqemis(5) = 2500.0
      freqemis(6) = 2857.0
      freqemis(7) = 3333.0

c ------------------------------------------
c       Calculate brightness temperatures for GOES
c ------------------------------------------
      do j=1,nl
        t(j)=prof(j)
        w(j)=prof(j + nl)
        o(j)=prof(j + 2 * nl)
      enddo
 
      emismw = 0.65
      do j = 1, ncemis
c       emisir(j) = 0.95
c       rhoir(j) = 0.05
        emisir(j) = 1.00
        rhoir(j) = 0.0
      enddo

      month = 12
     
      tskn = prof(3*nl+3)
      alat = prof(3*nl+5)
      alon = prof(3*nl+6)
      psurf= prof(3*nl+9)

      return
      end


      subroutine prepCube(prof,t,w,o,freqemis,emisir,rhoir,
     &  month,alat,alon,theta,psurf,tskn,emismw,ls,work)

      implicit none

      include 'incRTVL.f'
       
      integer*4 lsurface_gifts

      integer month, j, ls
      real*4 prof(lenp)
      real*4 t(nl),w(nl),o(nl)
      real*4 freqemis(ncemis), emisir(ncemis), rhoir(ncemis)
      real*4 alat, alon, theta, psurf, tskn, emismw
      real*4 work(nl)

      call parseCube(prof,t,w,o,freqemis,emisir,rhoir,
     &             month,alat,alon,theta,psurf,tskn,emismw,work)

c-----------------------------------------------------------------------
c     Use climatological mean ozone ine the upper 5 levels
c-----------------------------------------------------------------------
      call climozo101(alat,month, work)
      do j=1,5
        o(j)=work(j)
      enddo

      ls = lsurface_gifts (nl, p, psurf, 50.0, 1100.0)
      do j = ls+1,nl
        t(j) = t(ls)
        w(j) = w(ls)
        o(j) = o(ls)
      enddo

      return
      end

      subroutine renewProf(prof,profg,tg,wg,og,tskng,psurfg,pcg,cotg,ls)
      implicit none

      include 'incRTVL.f'
     
      integer*4 ls, i
      real*4 prof(lenp), profg(lenp)
      real*4 tg(nl), wg(nl), og(nl), tskng, psurfg,pcg,cotg

      do i=1,lenp
        profg(i)=prof(i)
      enddo

c t, w and o profiles
      do i=1,ls
        profg(i)=tg(i)
        profg(i+nl)=wg(i)
        profg(i+2*nl)=og(i)
      enddo

c terrain
      do i = ls+1, nl
        profg(i) = profg(ls)
        profg(nl+i) = profg(nl+ls)
        profg(2*nl+i) = profg(2*nl+ls)
      enddo

c skin temperature
      profg(3*nl+3) = tskng

c surface pressure (hPa)
c Make sure the units is the same as the true values
      profg(3*nl+9) = psurfg

c Pc  -- cloud pressure (hPa)
      profg(3*nl+7) = pcg      ! prof(3*nl+7) --> ltop
      profg(3*nl+8) = 9999.    ! prof(3*nl+8) --> itop

c COT
      profg(3*nl+1) = cotg     ! prof(3*nl+1) --> lwp
      profg(3*nl+2) = 9999.    ! prof(3*nl+2) --> iwp

      return
      end
